@@ -1,9 +1,14 @@
-# Copyright © 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
-from collections import Counter
+from typing import TYPE_CHECKING
 
 from jrnl.plugins.text_exporter import TextExporter
+from jrnl.plugins.util import get_journal_frequency_one_level
+
+if TYPE_CHECKING:
+    from jrnl.journals import Entry
+    from jrnl.journals import Journal
 
 
 class DatesExporter(TextExporter):
@@ -13,16 +18,12 @@ class DatesExporter(TextExporter):
     extension = "dates"
 
     @classmethod
-    def export_entry(cls, entry):
+    def export_entry(cls, entry: "Entry"):
         raise NotImplementedError
 
     @classmethod
-    def export_journal(cls, journal):
+    def export_journal(cls, journal: "Journal") -> str:
         """Returns dates and their frequencies for an entire journal."""
-        date_counts = Counter()
-        for entry in journal.entries:
-            # entry.date.date() gets date without time
-            date = str(entry.date.date())
-            date_counts[date] += 1
+        date_counts = get_journal_frequency_one_level(journal)
         result = "\n".join(f"{date}, {count}" for date, count in date_counts.items())
         return result
